@@ -80,7 +80,7 @@ class Tier(object):
     def configure_common_parsers(self, global_subparser):
         """ Common parsers for all tiers are configured here
         """
-        parser = global_subparser.add_parser(self.tier,
+        parser = global_subparser.add_parser(self.tier.lower(),
                                              help="Commands to monitor and control %s tier" % self.tier)
         self.tier_parser = parser.add_subparsers()
 
